using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using Syncfusion.Windows.Forms.Grid.Grouping;
using Syncfusion.Grouping;
using Syncfusion.Windows.Forms.Grid;

namespace CustomSummary
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            DataTable dt = new DataTable("MyTable");

            int nCols = 4;
            int nRows = 15;
            Random r = new Random(123345345);

            for (int i = 0; i < nCols; i++)
                dt.Columns.Add(new DataColumn(string.Format("Col{0}", i), typeof(int)));
             


            for (int i = 0; i < nRows; ++i)
            {
                DataRow dr = dt.NewRow();
                for (int j = 0; j < nCols; j++)
                    dr[j] = r.Next(10);
                 
                dt.Rows.Add(dr);
            }


            this.gridGroupingControl1.DataSource = dt;
            this.gridGroupingControl1.ShowGroupDropArea = true;

            //add some summaries

            GridSummaryColumnDescriptor sumCol2 = new GridSummaryColumnDescriptor("sumCol2", SummaryType.Int32Aggregate, "Col2", "{Sum}");
            GridSummaryColumnDescriptor sumCol3 = new GridSummaryColumnDescriptor("sumCol3", SummaryType.Int32Aggregate, "Col3", "{Sum}");


            //this serves as a place holder that will be populated in QueryCellStyleInfo
            GridSummaryColumnDescriptor sumCol1 = new GridSummaryColumnDescriptor("sumCol1", SummaryType.Custom, "Col1", "{Sum}");

            GridSummaryRowDescriptor sumRow = new GridSummaryRowDescriptor("sumRow", new GridSummaryColumnDescriptor[] { sumCol2, sumCol3, sumCol1 });
            sumRow.Appearance.AnySummaryCell.HorizontalAlignment = GridHorizontalAlignment.Right;

            gridGroupingControl1.TableDescriptor.SummaryRows.Add(sumRow);

            gridGroupingControl1.QueryCellStyleInfo += new GridTableCellStyleInfoEventHandler(gridGroupingControl1_QueryCellStyleInfo);

         }

        void gridGroupingControl1_QueryCellStyleInfo(object sender, GridTableCellStyleInfoEventArgs e)
        {
            if (e.TableCellIdentity.DisplayElement is GridSummaryRow
                  && e.TableCellIdentity.SummaryColumn != null 
                  && e.TableCellIdentity.SummaryColumn.Name == "sumCol1"
                )
            {
                GridSummaryRow row = e.TableCellIdentity.DisplayElement as GridSummaryRow;
                e.Style.BackColor = Color.LightGoldenrodYellow;
                double dCol2, dCol3;
                if (double.TryParse(GridEngine.GetSummaryText(row.ParentGroup, "sumRow", "sumCol2"), out dCol2)
                    && double.TryParse(GridEngine.GetSummaryText(row.ParentGroup, "sumRow", "sumCol3"), out dCol3)
                    && Math.Abs(dCol3) > .0000001)
                {
                    e.Style.CellValue = dCol2 / dCol3;
                }
                  
            }
        }

         
    }
}